@@ -8,6 +8,7 @@ Created on Thu August 10 23:52:55 2022
 import numpy as np
 import sympy as sym
 from pydae.urisi.vscs.ac3ph4wgfpi2 import ac3ph4wgfpi2
+from pydae.urisi.vscs.ac3ph4wgfpi3 import ac3ph4wgfpi3
 from pydae.urisi.vscs.ac_3ph_4w_l import ac_3ph_4w_l
 from pydae.urisi.vscs.acdc_3ph_4w_vdc_q import acdc_3ph_4w_vdc_q
 from pydae.urisi.vscs.acdc_3ph_4w_pq import acdc_3ph_4w_pq
@@ -22,6 +23,8 @@ def add_vscs(grid):
             ac_3ph_4w_l(grid,item)
         if item['type'] == 'ac3ph4wgfpi2':
             ac3ph4wgfpi2(grid,item)
+        if item['type'] == 'ac3ph4wgfpi3':
+            ac3ph4wgfpi3(grid,item)
         if item['type'] == 'acdc_3ph_4w_vdc_q': 
             acdc_3ph_4w_vdc_q(grid,item)
         if item['type'] == 'acdc_3ph_4w_pq': 
